@@ -131,7 +131,7 @@ int nn_ctcp_create (struct nn_ep *ep)
     self = nn_alloc (sizeof (struct nn_ctcp), "ctcp");
     alloc_assert (self);
 
-    /*  Initalise the endpoint. */
+    /*  Initialise the endpoint. */
     self->ep = ep;
     nn_ep_tran_setup (ep, &nn_ctcp_ep_ops, self);
 
@@ -439,7 +439,7 @@ static void nn_ctcp_handler (struct nn_fsm *self, int src, int type,
 /******************************************************************************/
 /*  WAITING state.                                                            */
 /*  Waiting before re-connection is attempted. This way we won't overload     */
-/*  the system by continuous re-connection attemps.                           */
+/*  the system by continuous re-connection attempts.                          */
 /******************************************************************************/
     case NN_CTCP_STATE_WAITING:
         switch (src) {
@@ -607,6 +607,7 @@ static void nn_ctcp_start_connecting (struct nn_ctcp *self,
     /*  Bind the socket to the local network interface. */
     rc = nn_usock_bind (&self->usock, (struct sockaddr*) &local, locallen);
     if (nn_slow (rc != 0)) {
+	nn_usock_stop (&self->usock);
         nn_backoff_start (&self->retry);
         self->state = NN_CTCP_STATE_WAITING;
         return;
